Enum TerminationReason

pub enum TerminationReason {
    NotYetTerminated,
    MaxIterationsReached,
    MaxFunctionEvaluationsReached,
    AbsoluteBracketToleranceSatisfied,
    RelativeBracketToleranceSatisfied,
    AbsoluteStepToleranceSatisfied,
    ValueToleranceSatisfied,
    ZeroDerivative,
    RootAtLowerBound,
    RootAtUpperBound,
}
Solver termination reasons.

Note

We derive the PartialEq trait to facilitate easier unit testing.

Variants



NotYetTerminated

Solver not yet terminated.



MaxIterationsReached

Solver terminated on reaching the maximum number of iterations.



MaxFunctionEvaluationsReached

Solver terminated on reaching the maximum number of function evaluations.



AbsoluteBracketToleranceSatisfied

Solver terminated on satisfying the absolute bracket tolerance.



RelativeBracketToleranceSatisfied

Solver terminated on satisfying the relative bracket tolerance.



AbsoluteStepToleranceSatisfied

Solver terminated on satisfying the absolute step tolerance.



ValueToleranceSatisfied

Solver terminated on satisfying the value tolerance.



ZeroDerivative

Solver terminated due to a zero derivative.

Note

This is only used for Newton’s method.



RootAtLowerBound

Solver terminated on finding a root at the lower bound of an initial interval.



RootAtUpperBound

Solver terminated on finding a root at the upper bound of an initial interval.